@@ -55,6 +55,12 @@ class QuestionAnswering(BenchmarkDataset):
         split: str = kwargs.pop("split")
         tokenizer: PreTrainedTokenizer = kwargs.pop("tokenizer")
 
+        # If the tokenizer is not a fast variant then raise an error
+        if not tokenizer.is_fast:
+            raise InvalidBenchmark(
+                "Question-answering benchmarks require a fast tokenizer."
+            )
+
         # Choose the preprocessing function depending on the dataset split
         if split == "test":
             preprocess_fn = partial(prepare_test_examples, tokenizer=tokenizer)
@@ -214,12 +220,13 @@ def prepare_train_examples(
 
         # Manually ensure that the special tokens are set to None in `sequence_ids`
         for special_token in tokenizer.special_tokens_map.keys():
-            special_token_id = getattr(tokenizer, f"{special_token}_id")
-            if special_token_id is not None:
-                sequence_ids = [
-                    None if token_id == special_token_id else seq_id
-                    for token_id, seq_id in zip(input_ids, sequence_ids)
-                ]
+            if hasattr(tokenizer, f"{special_token}_id"):
+                special_token_id = getattr(tokenizer, f"{special_token}_id")
+                if special_token_id is not None:
+                    sequence_ids = [
+                        None if token_id == special_token_id else seq_id
+                        for token_id, seq_id in zip(input_ids, sequence_ids)
+                    ]
 
         # One example can give several spans, this is the index of the example
         # containing this span of text.
